@@ -635,6 +635,10 @@ def _create_gltf_structure(scene,
             # fail here if data isn't json compatible
             # only export the extras if there is something there
             tree['scenes'][0]['extras'] = _jsonify(scene.metadata)
+            extensions = tree['scenes'][0]['extras'].pop(
+                'gltf_extensions', None)
+            if isinstance(extensions, dict):
+                tree['scenes'][0]['extensions'] = extensions
         except BaseException:
             log.debug(
                 'failed to export scene metadata!', exc_info=True)
@@ -685,6 +689,22 @@ def _create_gltf_structure(scene,
         scene=scene, mesh_index=mesh_index)
     tree.update(nodes)
 
+    extensions_used = set()
+    # Add any scene extensions used
+    if 'extensions' in tree['scenes'][0]:
+        extensions_used = extensions_used.union(
+            set(tree['scenes'][0]['extensions'].keys()))
+    # Add any mesh extensions used
+    for mesh in tree['meshes']:
+        if 'extensions' in mesh:
+            extensions_used = extensions_used.union(
+                set(mesh['extensions'].keys()))
+    # Add any extensions already in the tree (e.g. node extensions)
+    if 'extensionsUsed' in tree:
+        extensions_used = extensions_used.union(set(tree['extensionsUsed']))
+    if len(extensions_used) > 0:
+        tree['extensionsUsed'] = list(extensions_used)
+
     if buffer_postprocessor is not None:
         buffer_postprocessor(buffer_items, tree)
 
@@ -769,6 +789,11 @@ def _append_mesh(mesh,
         # skip jsonify any metadata, skipping internal keys
         current['extras'] = _jsonify(mesh.metadata)
 
+        # extract extensions if any
+        extensions = current['extras'].pop('gltf_extensions', None)
+        if isinstance(extensions, dict):
+            current['extensions'] = extensions
+
         if mesh.units not in [None, 'm', 'meters', 'meter']:
             current["extras"]["units"] = str(mesh.units)
     except BaseException:
@@ -802,7 +827,7 @@ def _append_mesh(mesh,
 
     if hasattr(mesh.visual, 'material'):
         # append the material and then set from returned index
-        current["primitives"][0]["material"] = _append_material(
+        current_material = _append_material(
             mat=mesh.visual.material,
             tree=tree,
             buffer_items=buffer_items,
@@ -825,8 +850,9 @@ def _append_mesh(mesh,
                                         "byteOffset": 0},
                                   data=uv.astype(float32))
             # add the reference for UV coordinates
-            current["primitives"][0]["attributes"][
-                "TEXCOORD_0"] = acc_uv
+            current["primitives"][0]["attributes"]["TEXCOORD_0"] = acc_uv
+            # only reference the material if we had UV coordinates
+            current["primitives"][0]["material"] = current_material
 
     if (include_normals or
         (include_normals is None and
@@ -1296,7 +1322,6 @@ def _read_buffers(header,
                 start = 0
             end = start + view["byteLength"]
             views[i] = buffers[view["buffer"]][start:end]
-
             assert len(views[i]) == view["byteLength"]
 
         # load data from buffers into numpy arrays
@@ -1308,6 +1333,7 @@ def _read_buffers(header,
             # what is the datatype
             dtype = np.dtype(_dtypes[a["componentType"]])
             # basically how many columns
+            # for types like (4, 4)
             per_item = _shapes[a["type"]]
             # use reported count to generate shape
             shape = np.append(count, per_item)
@@ -1336,7 +1362,7 @@ def _read_buffers(header,
                     # the total block we're looking at
                     length = count * stride
                     # we want to get the bytes for every row
-                    per_row = per_item * dtype.itemsize
+                    per_row = per_count * dtype.itemsize
                     # we have to offset the (already offset) buffer
                     # and then pull chunks per-stride
                     # do as a list comprehension as the numpy
@@ -1365,16 +1391,20 @@ def _read_buffers(header,
     # load data from accessors into Trimesh objects
     meshes = collections.OrderedDict()
 
-    names_original = collections.defaultdict(list)
-
+    # keep track of how many times each name has been attempted to
+    # be inserted to avoid a potentially slow search through our
+    # dict of names
+    name_counts = {}
     for index, m in enumerate(header.get("meshes", [])):
-
         try:
             # GLTF spec indicates implicit units are meters
             metadata = {'units': 'meters'}
             # try to load all mesh metadata
             if isinstance(m.get('extras'), dict):
                 metadata.update(m['extras'])
+            # put any mesh extensions in a field of the metadata
+            if 'extensions' in m:
+                metadata['gltf_extensions'] = m['extensions']
 
             for p in m["primitives"]:
                 # if we don't have a triangular mesh continue
@@ -1389,9 +1419,8 @@ def _read_buffers(header,
                 attr = p['attributes']
                 # create a unique mesh name per- primitive
                 name = m.get('name', 'GLTF')
-                names_original[index].append(name)
                 # make name unique across multiple meshes
-                name = unique_name(name, meshes)
+                name = unique_name(name, meshes, counts=name_counts)
 
                 if mode == _GL_LINES:
                     # load GL_LINES into a Path object
@@ -1409,8 +1438,8 @@ def _read_buffers(header,
                         if mode == _GL_STRIP:
                             # this is triangle strips
                             flat = access[p['indices']].reshape(-1)
-                            kwargs['faces'] = util.triangle_strips_to_faces([
-                                                                            flat])
+                            kwargs['faces'] = util.triangle_strips_to_faces(
+                                [flat])
                         else:
                             kwargs["faces"] = access[p["indices"]
                                                      ].reshape((-1, 3))
@@ -1463,7 +1492,6 @@ def _read_buffers(header,
                     # each primitive gets it's own Trimesh object
                     if len(m["primitives"]) > 1:
                         kwargs['metadata']['from_gltf_primitive'] = True
-                        name = unique_name(name, meshes)
                     else:
                         kwargs['metadata']['from_gltf_primitive'] = False
 
@@ -1545,9 +1573,13 @@ def _read_buffers(header,
     # to a dict comprehension as it will be checking
     # the mutated dict in every loop
     name_index = {}
+    name_counts = {}
     for i, n in enumerate(nodes):
         name_index[unique_name(
-            n.get('name', str(i)), name_index)] = i
+            n.get('name', str(i)),
+            name_index,
+            counts=name_counts
+        )] = i
     # invert the dict so we can look up by index
     # node index (int) : name (str)
     names = {v: k for k, v in name_index.items()}
@@ -1633,9 +1665,16 @@ def _read_buffers(header,
                 kwargs["matrix"],
                 np.diag(np.concatenate((child['scale'], [1.0]))))
 
-        if "extras" in child:
+        # treat node metadata similarly to mesh metadata
+        if isinstance(child.get("extras"), dict):
             kwargs["metadata"] = child["extras"]
 
+        # put any node extensions in a field of the metadata
+        if "extensions" in child:
+            if "metadata" not in kwargs:
+                kwargs["metadata"] = {}
+            kwargs["metadata"]["gltf_extensions"] = child["extensions"]
+
         if "mesh" in child:
             geometries = mesh_prim[child["mesh"]]
 
@@ -1644,7 +1683,7 @@ def _read_buffers(header,
                 # append root node
                 graph.append(kwargs.copy())
                 # put primitives as children
-                for i, geom_name in enumerate(geometries):
+                for geom_name in geometries:
                     # save the name of the geometry
                     kwargs["geometry"] = geom_name
                     # no transformations
@@ -1678,6 +1717,15 @@ def _read_buffers(header,
             header['scene']]['extras']
     except BaseException:
         pass
+    try:
+        # load any scene extensions into a field of scene.metadata
+        # use a try except to avoid nested key checks
+        if "metadata" not in result:
+            result["metadata"] = {}
+        result['metadata']['gltf_extensions'] = header['scenes'][
+            header['scene']]['extensions']
+    except BaseException:
+        pass
 
     return result
 
