@@ -10,8 +10,8 @@ try:
 except BaseException as E:
     # if someone tries to use Image re-raise
     # the import error so they can debug easily
-    from ..exceptions import ExceptionModule
-    Image = ExceptionModule(E)
+    from ..exceptions import ExceptionWrapper
+    Image = ExceptionWrapper(E)
 
 from .. import util
 from ..visual.color import to_float
@@ -131,24 +131,24 @@ def load_obj(file_obj,
         # maxsplit=1 means that it can stop working
         # after it finds the first newline
         # passed as arg as it's not a kwarg in python2
-        face_lines = [i.split('\n', 1)[0]
+        face_lines = [i.split('\n', 1)[0].strip()
                       for i in chunk.split('f ')[1:]]
 
-        # then we are going to replace all slashes with spaces
-        joined = ' '.join(face_lines).replace('/', ' ')
-
-        # the fastest way to get to a numpy array
-        # processes the whole string at once into a 1D array
-        array = np.fromstring(joined, sep=' ', dtype=np.int64)
-        # also wavefront is 1-indexed (vs 0-indexed) so offset
-        # only applies to positive indices
-        array[array > 0] -= 1
-
-        # get the number of raw 2D columns in a sample line
-        columns = len(face_lines[0].strip().replace('/', ' ').split())
+        # check every face for mixed tri-quad-ngon
+        columns = len(face_lines[0].replace('/', ' ').split())
+        flat_array = all(columns == len(f.replace('/', ' ').split())
+                         for f in face_lines)
 
         # make sure we have the right number of values for vectorized
-        if len(array) == (columns * len(face_lines)):
+        if flat_array:
+            # the fastest way to get to a numpy array
+            # processes the whole string at once into a 1D array
+            array = np.fromstring(' '.join(face_lines).replace('/', ' '),
+                                  sep=' ', dtype=np.int64)
+            # also wavefront is 1-indexed (vs 0-indexed) so offset
+            # only applies to positive indices
+            array[array > 0] -= 1
+
             # everything is a nice 2D array
             faces, faces_tex, faces_norm = _parse_faces_vectorized(
                 array=array,
@@ -748,6 +748,9 @@ def _preprocess_faces(text):
         elif chunk.startswith('usemtl'):
             current_mtl, chunk = chunk.split('\n', 1)
             current_mtl = current_mtl[6:].strip()
+        # Discard the g tag line in the list of faces
+        elif chunk.startswith('g '):
+            _, chunk = chunk.split('\n', 1)
         if 'f ' in chunk:
             face_tuples.append((current_mtl, current_obj, chunk))
     return face_tuples
@@ -932,7 +935,7 @@ def export_obj(mesh,
         mtl_data = {}
         # now loop through: keys are garbage hash
         # values are (data, name)
-        for data, name in materials.values():
+        for data, _ in materials.values():
             for file_name, file_data in data.items():
                 if file_name.lower().endswith('.mtl'):
                     # collect mtl lines into single file
