@@ -17,7 +17,7 @@ _stl_dtype = np.dtype([('normals', '<f4', (3)),
                        ('attributes', '<u2')])
 # define a numpy datatype for the header of a binary STL file
 _stl_dtype_header = np.dtype([('header', np.void, 80),
-                              ('face_count', '<i4')])
+                              ('face_count', '<u4')])
 
 
 def load_stl(file_obj, **kwargs):
@@ -78,8 +78,8 @@ def load_stl_binary(file_obj):
         raise HeaderError('Binary STL shorter than a fixed header!')
 
     try:
-        header = np.frombuffer(header_data,
-                               dtype=_stl_dtype_header)
+        header = np.frombuffer(
+            header_data, dtype=_stl_dtype_header)
     except BaseException:
         raise HeaderError('Binary header incorrect type')
 
