@@ -8,6 +8,7 @@ from . import lighting
 from .. import util
 from .. import units
 from .. import convex
+from .. import inertia
 from .. import caching
 from .. import grouping
 from .. import transformations
@@ -30,7 +31,7 @@ class Scene(Geometry3D):
     def __init__(self,
                  geometry=None,
                  base_frame='world',
-                 metadata={},
+                 metadata=None,
                  graph=None,
                  camera=None,
                  lights=None,
@@ -69,7 +70,8 @@ class Scene(Geometry3D):
 
         # hold metadata about the scene
         self.metadata = {}
-        self.metadata.update(metadata)
+        if isinstance(metadata, dict):
+            self.metadata.update(metadata)
 
         if graph is not None:
             # if we've been passed a graph override the default
@@ -105,7 +107,7 @@ class Scene(Geometry3D):
                      geom_name=None,
                      parent_node_name=None,
                      transform=None,
-                     extras=None):
+                     metadata=None):
         """
         Add a geometry to the scene.
 
@@ -117,11 +119,16 @@ class Scene(Geometry3D):
         ----------
         geometry : Trimesh, Path2D, Path3D PointCloud or list
           Geometry to initially add to the scene
-        node_name: Name of the added node.
-        geom_name: Name of the added geometry.
-        parent_node_name: Name of the parent node in the graph.
-        transform: Transform that applies to the added node.
-        extras: Optional metadata for the node.
+        node_name : None or str
+          Name of the added node.
+        geom_name : None or str
+          Name of the added geometry.
+        parent_node_name : None or str
+          Name of the parent node in the graph.
+        transform : None or (4, 4) float
+          Transform that applies to the added node.
+        metadata : None or dict
+          Optional metadata for the node.
 
         Returns
         ----------
@@ -141,11 +148,13 @@ class Scene(Geometry3D):
                 geom_name=geom_name,
                 parent_node_name=parent_node_name,
                 transform=transform,
-                extras=extras) for value in geometry]
+                metadata=metadata) for value in geometry]
         elif isinstance(geometry, dict):
             # if someone passed us a dict of geometry
-            return {k: self.add_geometry(v, geom_name=k, extras=extras)
-                    for k, v in geometry.items()}
+            return {k: self.add_geometry(
+                    geometry=v,
+                    geom_name=k,
+                    metadata=metadata) for k, v in geometry.items()}
 
         elif isinstance(geometry, Scene):
             # concatenate current scene with passed scene
@@ -158,7 +167,7 @@ class Scene(Geometry3D):
             return
 
         if not hasattr(geometry, 'vertices'):
-            util.log.warning('unknown type ({}) added to scene!'.format(
+            util.log.debug('unknown type ({}) added to scene!'.format(
                 type(geometry).__name__))
             return
 
@@ -199,7 +208,7 @@ class Scene(Geometry3D):
                           matrix=transform,
                           geometry=name,
                           geometry_flags={'visible': True},
-                          extras=extras)
+                          metadata=metadata)
 
         return node_name
 
@@ -389,6 +398,68 @@ class Scene(Geometry3D):
         centroid = np.mean(self.bounds, axis=0)
         return centroid
 
+    @caching.cache_decorator
+    def center_mass(self):
+        """
+        Find the center of mass for every instance in the scene.
+
+        Returns
+        ------------
+        center_mass : (3,) float
+          The center of mass of the scene
+        """
+        # get the center of mass and volume for each geometry
+        center_mass = {k: m.center_mass for k, m in self.geometry.items()
+                       if hasattr(m, 'center_mass')}
+        mass = {k: m.mass for k, m in self.geometry.items()
+                if hasattr(m, 'mass')}
+
+        # get the geometry name and transform for each instance
+        graph = self.graph
+        instance = [graph[n] for n in graph.nodes_geometry]
+
+        # get the transformed center of mass for each instance
+        transformed = np.array(
+            [np.dot(mat, np.append(center_mass[g], 1))[:3]
+             for mat, g in instance
+             if g in center_mass], dtype=np.float64)
+        # weight the center of mass locations by volume
+        weights = np.array(
+            [mass[g] for _, g in instance], dtype=np.float64)
+        weights /= weights.sum()
+        return (transformed * weights.reshape((-1, 1))).sum(axis=0)
+
+    @caching.cache_decorator
+    def moment_inertia(self):
+        """
+        Return the moment of inertia of the current scene with
+        respect to the center of mass of the current scene.
+
+        Returns
+        ------------
+        inertia : (3, 3) float
+          Inertia with respect to cartesian axis at `scene.center_mass`
+        """
+        return inertia.scene_inertia(
+            scene=self,
+            transform=transformations.translation_matrix(self.center_mass))
+
+    def moment_inertia_frame(self, transform):
+        """
+        Return the moment of inertia of the current scene relative
+        to a transform from the base frame.
+
+        Parameters
+        transform : (4, 4) float
+          Homogeneous transformation matrix.
+
+        Returns
+        -------------
+        inertia : (3, 3) float
+          Inertia tensor at requested frame.
+        """
+        return inertia.scene_inertia(scene=self, transform=transform)
+
     @caching.cache_decorator
     def area(self):
         """
@@ -407,6 +478,24 @@ class Scene(Geometry3D):
         return sum((areas.get(self.graph[n][1], 0.0) for n in
                     self.graph.nodes_geometry), 0.0)
 
+    @caching.cache_decorator
+    def volume(self):
+        """
+        What is the summed volume of every geometry which
+        has volume
+
+        Returns
+        ------------
+        volume : float
+          Summed area of every instanced geometry
+        """
+        # get the area of every geometry that has a volume attribute
+        volume = {n: g.volume for n, g in self.geometry.items()
+                  if hasattr(g, 'area')}
+        # sum the area including instancing
+        return sum((volume.get(self.graph[n][1], 0.0) for n in
+                    self.graph.nodes_geometry), 0.0)
+
     @caching.cache_decorator
     def triangles(self):
         """
@@ -1029,8 +1118,8 @@ class Scene(Geometry3D):
                             parent_node_name=p,
                             transform=result.graph.transforms.edge_data[(
                                 p, n)].get('matrix', None),
-                            extras=result.graph.transforms.edge_data[(
-                                p, n)].get('extras', None))
+                            metadata=result.graph.transforms.edge_data[(
+                                p, n)].get('metadata', None))
                     result.delete_geometry(geom_name)
 
             # Convert all 2D paths to 3D paths
@@ -1233,7 +1322,7 @@ def split_scene(geometry, **kwargs):
     return scene
 
 
-def append_scenes(iterable, common=['world'], base_frame='world'):
+def append_scenes(iterable, common=None, base_frame='world'):
     """
     Concatenate multiple scene objects into one scene.
 
@@ -1254,6 +1343,9 @@ def append_scenes(iterable, common=['world'], base_frame='world'):
     if isinstance(iterable, Scene):
         return iterable
 
+    if common is None:
+        common = [base_frame]
+
     # save geometry in dict
     geometry = {}
     # save transforms as edge tuples
