@@ -52,10 +52,10 @@ def area(triangles=None, crosses=None, sum=False):
     """
     if crosses is None:
         crosses = cross(triangles)
-    area = (np.sum(crosses**2, axis=1)**.5) * .5
+    areas = np.sqrt((crosses ** 2).sum(axis=1)) / 2.0
     if sum:
-        return np.sum(area)
-    return area
+        return areas.sum()
+    return areas
 
 
 def normals(triangles=None, crosses=None):
@@ -266,11 +266,11 @@ def mass_properties(triangles,
         (volume * (center_mass[[0, 2]]**2).sum())
     inertia[2, 2] = integrated[4] + integrated[5] - \
         (volume * (center_mass[[0, 1]]**2).sum())
-    inertia[0, 1] = (
+    inertia[0, 1] = - (
         integrated[7] - (volume * np.product(center_mass[[0, 1]])))
-    inertia[1, 2] = (
+    inertia[1, 2] = - (
         integrated[8] - (volume * np.product(center_mass[[1, 2]])))
-    inertia[0, 2] = (
+    inertia[0, 2] = - (
         integrated[9] - (volume * np.product(center_mass[[0, 2]])))
     inertia[2, 0] = inertia[0, 2]
     inertia[2, 1] = inertia[1, 2]
@@ -313,7 +313,7 @@ def windings_aligned(triangles, normals_compare):
         difference = diagonal_dot(
             calculated, normals_compare[valid])
 
-    aligned = np.zeros(len(triangles), dtype=np.bool)
+    aligned = np.zeros(len(triangles), dtype=bool)
     aligned[valid] = difference > 0.0
 
     return aligned
@@ -575,7 +575,7 @@ def closest_point(triangles, points):
     # store the location of the closest point
     result = np.zeros_like(points)
     # which points still need to be handled
-    remain = np.ones(len(points), dtype=np.bool)
+    remain = np.ones(len(points), dtype=bool)
 
     # if we dot product this against a (n, 3)
     # it is equivalent but faster than array.sum(axis=1)
@@ -598,7 +598,7 @@ def closest_point(triangles, points):
 
     # is the point at A
     is_a = np.logical_and(d1 < tol.zero, d2 < tol.zero)
-    if is_a.any():
+    if any(is_a):
         result[is_a] = a[is_a]
         remain[is_a] = False
 
@@ -609,7 +609,7 @@ def closest_point(triangles, points):
 
     # do the logic check
     is_b = (d3 > -tol.zero) & (d4 <= d3) & remain
-    if is_b.any():
+    if any(is_b):
         result[is_b] = b[is_b]
         remain[is_b] = False
 
@@ -618,7 +618,7 @@ def closest_point(triangles, points):
     is_ab = ((vc < tol.zero) &
              (d1 > -tol.zero) &
              (d3 < tol.zero) & remain)
-    if is_ab.any():
+    if any(is_ab):
         v = (d1[is_ab] / (d1[is_ab] - d3[is_ab])).reshape((-1, 1))
         result[is_ab] = a[is_ab] + (v * ab[is_ab])
         remain[is_ab] = False
@@ -628,14 +628,14 @@ def closest_point(triangles, points):
     d5 = np.dot(ab * cp, ones)
     d6 = np.dot(ac * cp, ones)
     is_c = (d6 > -tol.zero) & (d5 <= d6) & remain
-    if is_c.any():
+    if any(is_c):
         result[is_c] = c[is_c]
         remain[is_c] = False
 
     # check if P in edge region of AC, if so return projection of P onto AC
     vb = (d5 * d2) - (d1 * d6)
     is_ac = (vb < tol.zero) & (d2 > -tol.zero) & (d6 < tol.zero) & remain
-    if is_ac.any():
+    if any(is_ac):
         w = (d2[is_ac] / (d2[is_ac] - d6[is_ac])).reshape((-1, 1))
         result[is_ac] = a[is_ac] + w * ac[is_ac]
         remain[is_ac] = False
@@ -645,14 +645,14 @@ def closest_point(triangles, points):
     is_bc = ((va < tol.zero) &
              ((d4 - d3) > - tol.zero) &
              ((d5 - d6) > -tol.zero) & remain)
-    if is_bc.any():
+    if any(is_bc):
         d43 = d4[is_bc] - d3[is_bc]
         w = (d43 / (d43 + (d5[is_bc] - d6[is_bc]))).reshape((-1, 1))
         result[is_bc] = b[is_bc] + w * (c[is_bc] - b[is_bc])
         remain[is_bc] = False
 
     # any remaining points must be inside face region
-    if remain.any():
+    if any(remain):
         # point is inside face region
         denom = 1.0 / (va[remain] + vb[remain] + vc[remain])
         v = (vb[remain] * denom).reshape((-1, 1))
